#+TITLE: Bug in multiline strings in ob-js.el

This org-mode file describes a bug in ob-js.el and proposes a solution.

* Problem Description
Let's say I have a multi-line string stored in an example block.

I want to store my CSV in an example block.

#+NAME: my-csv-data
#+BEGIN_EXAMPLE
  ColA,ColB,ColC
  1,2,3
  4,5,6
#+END_EXAMPLE

I have a JavaScript function that accepts a string named 'csv' and passing in 'my-csv-data'.

#+BEGIN_SRC js :var csv=my-csv-data :results output
  console.log(csv);
#+END_SRC

When I expand the source block I end up with:

#+BEGIN_SRC js
var csv="ColA,ColB,ColC
  1,2,3
  4,5,6";
console.log(csv);
#+END_SRC

This will not execute correctly because JavaScript does not support newlines in strings.

What I want instead is:

#+BEGIN_SRC js
  var csv="ColA,ColB,ColC\n  1,2,3\n  4,5,6";
  console.log(csv);
#+END_SRC

* Proposed Fix

  To fix this problem I changed function "org-babel-js-var-to-js" in ob-js.el:116.

  #+BEGIN_SRC emacs-lisp
    (defun org-babel-js-var-to-js (var)
      "Convert VAR into a js variable.
    Convert an elisp value into a string of js source code
    specifying a variable of the same value."
      (if (listp var)
          (concat "[" (mapconcat #'org-babel-js-var-to-js var ", ") "]")
        (format "%S" var)))
  #+END_SRC

  to

  #+BEGIN_SRC emacs-lisp
    (defun org-babel-js-var-to-js (var)
      "Convert VAR into a js variable.
    Convert an elisp value into a string of js source code
    specifying a variable of the same value."
      (if (listp var)
          (concat "[" (mapconcat #'org-babel-js-var-to-js var ", ") "]")
        (replace-regexp-in-string "\n" "\\\\n" (format "%S" var))))
  #+END_SRC
